@@ -41,4 +41,23 @@ PyObject* DateConverter::toPyObject(int64_t rowIndex) const
   }
 }
 
+NumpyDateConverter::NumpyDateConverter(std::shared_ptr<arrow::Array> array, PyObject * context)
+: m_array(std::dynamic_pointer_cast<arrow::Date32Array>(array)),
+  m_context(context)
+{
+}
+
+PyObject* NumpyDateConverter::toPyObject(int64_t rowIndex) const
+{
+  if (m_array->IsValid(rowIndex))
+  {
+    int32_t deltaDays = m_array->Value(rowIndex);
+    return PyObject_CallMethod(m_context, "DATE_to_numpy_datetime64", "i", deltaDays);
+  }
+  else
+  {
+    Py_RETURN_NONE;
+  }
+}
+
 }  // namespace sf
