@@ -20,6 +20,19 @@ private:
   std::shared_ptr<arrow::DoubleArray> m_array;
 };
 
+class NumpyFloat64Converter : public IColumnConverter
+{
+public:
+  explicit NumpyFloat64Converter(std::shared_ptr<arrow::Array> array, PyObject * context);
+
+  PyObject* toPyObject(int64_t rowIndex) const override;
+
+private:
+  std::shared_ptr<arrow::DoubleArray> m_array;
+
+  PyObject * m_context;
+};
+
 }  // namespace sf
 
 #endif  // PC_FLOATCONVERTER_HPP
