@@ -3,6 +3,7 @@
 #
 # Copyright (c) 2012-2019 Snowflake Computing Inc. All right reserved.
 #
+import os
 import platform
 import sys
 import warnings
@@ -12,13 +13,18 @@ from datetime import datetime, timezone
 from logging import getLogger
 from os import getenv
 
+from Cryptodome.Hash import SHA1, SHA256, SHA384, SHA512
+from Cryptodome.PublicKey import RSA
+from Cryptodome.Signature import PKCS1_v1_5
 from asn1crypto.algos import DigestAlgorithm
 from asn1crypto.core import Integer, OctetString
 from asn1crypto.ocsp import CertId, OCSPRequest, OCSPResponse, Request, Requests, TBSRequest, Version
 from asn1crypto.x509 import Certificate
-from Cryptodome.Hash import SHA1, SHA256, SHA384, SHA512
-from Cryptodome.PublicKey import RSA
-from Cryptodome.Signature import PKCS1_v1_5
+from cryptography.exceptions import InvalidSignature
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import serialization, hashes
+from cryptography.hazmat.primitives.asymmetric import padding, utils
+
 from snowflake.connector.errorcode import ER_INVALID_OCSP_RESPONSE, ER_INVALID_OCSP_RESPONSE_CODE
 from snowflake.connector.errors import RevocationCheckError
 from snowflake.connector.ocsp_snowflake import SnowflakeOCSP
@@ -49,6 +55,12 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         'sha512': SHA512,
     }
 
+    SIGNATURE_ALGORITHM_TO_DIGEST_CLASS_OPENSSL = {
+        'sha256': hashes.SHA256,
+        'sha384': hashes.SHA3_384,
+        'sha512': hashes.SHA3_512,
+    }
+
     WILDCARD_CERTID = None
 
     def __init__(self, **kwargs):
@@ -88,15 +100,14 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         if storage is None:
             storage = SnowflakeOCSP.ROOT_CERTIFICATES_DICT
         logger.debug('reading certificate bundle: %s', ca_bundle_file)
-        all_certs = open(ca_bundle_file, 'rb').read()
-
-        # don't lock storage
-        from asn1crypto import pem
-        pem_certs = pem.unarmor(all_certs, multiple=True)
-        for type_name, _, der_bytes in pem_certs:
-            if type_name == 'CERTIFICATE':
-                crt = Certificate.load(der_bytes)
-                storage[crt.subject.sha256] = crt
+        with open(ca_bundle_file, 'rb') as all_certs:
+            # don't lock storage
+            from asn1crypto import pem
+            pem_certs = pem.unarmor(all_certs.read(), multiple=True)
+            for type_name, _, der_bytes in pem_certs:
+                if type_name == 'CERTIFICATE':
+                    crt = Certificate.load(der_bytes)
+                    storage[crt.subject.sha256] = crt
 
     def create_ocsp_request(self, issuer, subject):
         """
@@ -320,21 +331,48 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
             raise RevocationCheckError(msg=debug_msg, errno=op_er.errno)
 
     def verify_signature(self, signature_algorithm, signature, cert, data):
-        pubkey = asymmetric.load_public_key(cert.public_key).unwrap().dump()
-        rsakey = RSA.importKey(pubkey)
-        signer = PKCS1_v1_5.new(rsakey)
-        if signature_algorithm in SnowflakeOCSPAsn1Crypto.SIGNATURE_ALGORITHM_TO_DIGEST_CLASS:
-            digest = \
-                SnowflakeOCSPAsn1Crypto.SIGNATURE_ALGORITHM_TO_DIGEST_CLASS[
+        use_openssl_only = os.getenv('USE_OPENSSL_ONLY', 'False') == 'True'
+        if not use_openssl_only:
+            pubkey = asymmetric.load_public_key(cert.public_key).unwrap().dump()
+            rsakey = RSA.importKey(pubkey)
+            signer = PKCS1_v1_5.new(rsakey)
+            if signature_algorithm in SnowflakeOCSPAsn1Crypto.SIGNATURE_ALGORITHM_TO_DIGEST_CLASS:
+                digest = \
+                    SnowflakeOCSPAsn1Crypto.SIGNATURE_ALGORITHM_TO_DIGEST_CLASS[
                     signature_algorithm].new()
+            else:
+                # the last resort. should not happen.
+                digest = SHA1.new()
+            digest.update(data.dump())
+            if not signer.verify(digest, signature):
+                raise RevocationCheckError(
+                    msg="Failed to verify the signature",
+                    errno=ER_INVALID_OCSP_RESPONSE)
+
         else:
-            # the last resort. should not happen.
-            digest = SHA1.new()
-        digest.update(data.dump())
-        if not signer.verify(digest, signature):
-            raise RevocationCheckError(
-                msg="Failed to verify the signature",
-                errno=ER_INVALID_OCSP_RESPONSE)
+            backend = default_backend()
+            public_key = serialization.load_der_public_key(cert.public_key.dump(), backend=default_backend())
+            if signature_algorithm in SnowflakeOCSPAsn1Crypto.SIGNATURE_ALGORITHM_TO_DIGEST_CLASS:
+                chosen_hash = \
+                    SnowflakeOCSPAsn1Crypto.SIGNATURE_ALGORITHM_TO_DIGEST_CLASS_OPENSSL[
+                        signature_algorithm]()
+            else:
+                # the last resort. should not happen.
+                chosen_hash = hashes.SHA1()
+            hasher = hashes.Hash(chosen_hash, backend)
+            hasher.update(data.dump())
+            digest = hasher.finalize()
+            try:
+                public_key.verify(
+                    signature,
+                    digest,
+                    padding.PKCS1v15(),
+                    utils.Prehashed(chosen_hash)
+                )
+            except InvalidSignature:
+                raise RevocationCheckError(
+                    msg="Failed to verify the signature",
+                    errno=ER_INVALID_OCSP_RESPONSE)
 
     def extract_certificate_chain(self, connection):
         """
