@@ -2,6 +2,7 @@ from .errors import MissingDependencyError
 
 # Flags to see whether optional dependencies were installed
 installed_pandas = False
+installed_keyring = False
 
 
 class MissingPandas(object):
@@ -10,6 +11,12 @@ class MissingPandas(object):
         raise MissingDependencyError('pandas')
 
 
+class MissingKeyring(object):
+
+    def __getattr__(self, item):
+        raise MissingDependencyError('keyring')
+
+
 try:
     import pandas
     import pyarrow
@@ -17,3 +24,9 @@ try:
 except ImportError:
     pandas = MissingPandas()
     pyarrow = MissingPandas()
+
+try:
+    import keyring
+    installed_keyring = True
+except ImportError:
+    keyring = MissingKeyring()
